@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-470c7d439aebaa15316f9879291ea266
-key: authe_IUQ4ZhEJzJA977XyjLXNMo
+id: authenticate-1.3.3-0af1b89fe7385b681d2d488a8f776d68
+key: authe_CoNMfqHQ2HAF0iNys4hCqM
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,26 +23,26 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-IUQ4ZhEJzJA977XyjLXNMo
+hs-libraries: HSauthenticate-1.3.3-CoNMfqHQ2HAF0iNys4hCqM
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c798f9d7ea7ba5a96fa5679d606aad7f
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-3cbd23ba75c7bf6ee8e4c2285c87f4dc
-    http-types-0.9-181a315082d46c3ed5dffe75933f2447
+    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
+    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    tagstream-conduit-0.5.5.3-df4e7788e0f16bef32f58236faf47219
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    tagstream-conduit-0.5.5.3-527b907f2f898027d51ce23ff30849e3
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
-    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
+    xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
